@@ -9,4 +9,4 @@ from .. import APP_NAME, PROJECT_NAME, APP_BASE
 
 @view_config(route_name=APP_NAME+'.home', renderer='%s:templates/list.mako' % APP_BASE)
 def my_view(request):
-    return {}
+    return {'APP_BASE': APP_BASE}
