@@ -3,17 +3,17 @@ from mako import runtime, filters, cache
 UNDEFINED = runtime.UNDEFINED
 __M_dict_builtin = dict
 __M_locals_builtin = locals
-_magic_number = 6
-_modified_time = 1326428737.681867
-_template_filename='/mnt/md0/MyWork/MyProjects/PyCK/pyck/forms/templates/form_as_p.mako'
-_template_uri='form_as_p.mako'
-_template_cache=cache.Cache(__name__, _modified_time)
-_source_encoding='ascii'
+_magic_number = 8
+_modified_time = 1334581848.684365
+_enable_loop = True
+_template_filename = '/mnt/md0/MyWork/MyProjects/PyCK/pyck/forms/templates/form_as_p.mako'
+_template_uri = 'form_as_p.mako'
+_source_encoding = 'ascii'
 _exports = []
 
 
 def render_body(context,**pageargs):
-    context.caller_stack._push_frame()
+    __M_caller = context.caller_stack._push_frame()
     try:
         __M_locals = __M_dict_builtin(pageargs=pageargs)
         errors_position = context.get('errors_position', UNDEFINED)
